
Client-side authentication
-------

**Description:**

An application could implement authentication functionalities through JavaScript and HTML. 
However, these are client-side constraints that are imposed, which means that a hacker 
can easily disable or modify these constraints.


**Solution:**

Never implement client-side authentication constraints, since these are easily bypassed. 
When implementing authentication methods always use server-side solutions.

	